one2manydelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# one2manydelegate

class `camelot.view.controls.delegates.one2manydelegate.` `One2ManyDelegate`(parent=None, **kwargs)

  Custom delegate for many 2 one relations

  Field attributes supported by the delegate :

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus